package App::Bin4TSV::8 ;  
our $VERSION = '0.110' ; 
our $DATE = '2021-06-29T01:01+09:00'

=encoding utf8

=head1 NAME

App::Bin4TSV::9

=head1 SYNOPSIS

This module provides a Unix-like commands of :  

  colgrep
  colsummary
  crosstable 
  csel
  csv2tsv
  digitdemog
  expandtab
  freq
  venn
 
=head1 DESCRIPTION



=head1 SEE ALSO


=cut

1 ;
